@@ -4,8 +4,7 @@
 #include "kdevelop_version.h"
 
 #define KDEV_ITEMREPOSITORY_VERSION (KDEVELOP_VERSION_MAJOR << 24) \
-                                  + (KDEVELOP_VERSION_MINOR << 16) \
-                                  + (KDEVELOP_VERSION_PATCH << 8) \
+                                  + (9 << 16) \
                                   + 3
 
 #endif
